@@ -241,6 +241,8 @@ var annotated_dup =
     [ "spa_support", "structspa__support.html", "structspa__support" ],
     [ "spa_system", "structspa__system.html", "structspa__system" ],
     [ "spa_system_methods", "structspa__system__methods.html", "structspa__system__methods" ],
+    [ "spa_thread_utils", "structspa__thread__utils.html", "structspa__thread__utils" ],
+    [ "spa_thread_utils_methods", "structspa__thread__utils__methods.html", "structspa__thread__utils__methods" ],
     [ "spa_type_info", "structspa__type__info.html", "structspa__type__info" ],
     [ "spa_video_colorimetry", "structspa__video__colorimetry.html", "structspa__video__colorimetry" ],
     [ "spa_video_info", "structspa__video__info.html", "structspa__video__info" ],
@@ -250,6 +252,7 @@ var annotated_dup =
     [ "spa_video_info_raw", "structspa__video__info__raw.html", "structspa__video__info__raw" ],
     [ "stream", "structstream.html", "structstream" ],
     [ "support", "structsupport.html", "structsupport" ],
+    [ "thread", "structthread.html", "structthread" ],
     [ "tunnel", "structtunnel.html", "structtunnel" ],
     [ "tunnel_info", "structtunnel__info.html", "structtunnel__info" ]
 ];
\ No newline at end of file
