@@ -5,6 +5,7 @@ var globals_defs =
     [ "b", "globals_defs_b.html", null ],
     [ "c", "globals_defs_c.html", null ],
     [ "d", "globals_defs_d.html", null ],
+    [ "e", "globals_defs_e.html", null ],
     [ "f", "globals_defs_f.html", null ],
     [ "h", "globals_defs_h.html", null ],
     [ "i", "globals_defs_i.html", null ],
@@ -17,5 +18,6 @@ var globals_defs =
     [ "r", "globals_defs_r.html", null ],
     [ "s", "globals_defs_s.html", null ],
     [ "t", "globals_defs_t.html", null ],
+    [ "u", "globals_defs_u.html", null ],
     [ "v", "globals_defs_v.html", null ]
 ];
\ No newline at end of file
